/*  This file is part of ksquirrel-libs (http://ksquirrel.sf.net)

    Copyright (c) 2005 Dmitry Baryshev <ksquirrel@tut.by>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation;
    either version 2 of the License, or (at your option) any later
    version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef KSQUIRREL_LIBS_CLASS_DEFINITION_create_destroy_H
#define KSQUIRREL_LIBS_CLASS_DEFINITION_create_destroy_H

#include "ksquirrel-libs/ksquirrel_libs_export.h"

extern "C" LIBKSQUIRREL_EXPORT fmt_codec_base* codec_create()
{
    return (new fmt_codec);
}

extern "C" LIBKSQUIRREL_EXPORT void codec_destroy(fmt_codec_base *p)
{
    delete p;
}

#endif
